@@ -8,21 +8,21 @@ from .utils import update_record_file_contents
 
 
 def get_files(**kwargs):
-    metadata_directory = kwargs.get('metadata_directory', '')
+    metadata_directory = kwargs.get("metadata_directory", "")
 
     files = []
     for f in get_template_files(**kwargs):
-        if str(f.path) == 'LICENSE.txt':
-            files.append(File(Path(metadata_directory, 'licenses', f.path), f.contents))
+        if str(f.path) == "LICENSE.txt":
+            files.append(File(Path(metadata_directory, "licenses", f.path), f.contents))
 
-        if f.path.parts[0] != 'src':
+        if f.path.parts[0] != "src":
             continue
 
         files.append(File(Path(*f.path.parts[1:]), f.contents))
 
     files.extend((
         File(
-            Path(metadata_directory, 'WHEEL'),
+            Path(metadata_directory, "WHEEL"),
             f"""\
 Wheel-Version: 1.0
 Generator: hatchling {__version__}
@@ -32,17 +32,17 @@ Tag: py3-none-any
 """,
         ),
         File(
-            Path(metadata_directory, 'METADATA'),
+            Path(metadata_directory, "METADATA"),
             f"""\
 Metadata-Version: {DEFAULT_METADATA_VERSION}
-Name: {kwargs['project_name']}
+Name: {kwargs["project_name"]}
 Version: 0.0.1
 License-File: LICENSE.txt
 """,
         ),
     ))
 
-    record_file = File(Path(metadata_directory, 'RECORD'), '')
+    record_file = File(Path(metadata_directory, "RECORD"), "")
     update_record_file_contents(record_file, files)
     files.append(record_file)
 
